bmscanner

package module
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 19, 2026 License: MIT Imports: 11 Imported by: 0

README

bmscanner

Scan bms packages

Documentation

Overview

Package bmscanner scan bms packages

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Package

type Package struct {
	PackageName      string
	PackageDirectory string
	ShardMD5         string
	Models           []sprout.BMSModel
	FileManifest     map[string]int
	BannerFileName   string
	BackBMPFileName  string
	StageFileName    string
}

type ScanResult

type ScanResult struct {
	Err        error
	Candidates []Package
}

type Scanner

type Scanner struct {
	// contains filtered or unexported fields
}

Scanner is a helper that manages a process of scanning. It's obvious that scanning directories, parsing files are heavy tasks. So the api of scanner is designed to be async

func NewScanner

func NewScanner() *Scanner

func (*Scanner) Query

func (sc *Scanner) Query() int

Query returns the current scanned packages count

func (*Scanner) Scan

func (sc *Scanner) Scan(dir string) <-chan ScanResult

Scan triggers a scanning process, which starts at directory 'dir'

Directories

Path Synopsis
internal
mp
Package mp
Package mp

Jump to