Documentation
¶
Overview ¶
Package bmscanner scan bms packages
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ScanResult ¶
type Scanner ¶
type Scanner struct {
// contains filtered or unexported fields
}
Scanner is a helper that manages a process of scanning. It's obvious that scanning directories, parsing files are heavy tasks. So the api of scanner is designed to be async
func NewScanner ¶
func NewScanner() *Scanner
func (*Scanner) Scan ¶
func (sc *Scanner) Scan(dir string) <-chan ScanResult
Scan triggers a scanning process, which starts at directory 'dir'
Click to show internal directories.
Click to hide internal directories.